extensions [profiler nw]

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Globals
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
globals [
  ;model variables
  price_list
  price_list_temp        ;;;;;;;;; probably goes later
  directory-name           ; where the journal goes
  file-name                ; journal name
  dat
  order_bank
  order_bank_all
  temp2
  buying  buying_list
  selling selling_list
  action_bank_all
  return
  return_list
  return_list_t-1
  esembled_average_t-1
  esembled_average
  stddev_rt_1
  stddev_rt
  newpricelog
  public_info
  public_info_t-1
  assets_list
  asset_counter
  factor
  asset_0_news
  dividends
  network_trust
  publicscore
  public_trust
  ; Network data
  average_betweenness
  average_closeness
  average_eigen
  std_betweenness
  std_closeness
  std_eigen
  ; Efficient frontier variables
  stdevpr_list
  avepr_list
  effaave
  effastd
]

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Breeds/Classes
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

breed [assets asset]
breed [investors investor]
undirected-link-breed [connections connection]

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Ownership
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

assets-own
[eps consensus_eps ensemble_eps_t-1 eps_dev H&S_dev eps_history eps_mean bid_vol ask_vol ave_return stddev_a_rt beta

  consensus_accuracy consensus_accuracy_history price dps a_rt stdevrt rti]

investors-own [
  ID
  private_info    ; private news values for each asset
  network_info    ; weighted score of neighbors for each asset
  network_info_t-1
  neighbor_list
  neighbor_trust  ;
  neighbor_trust_temp   ;
  neighbor_info
  num_neighbors
  cash
  dividend_bank
  portfolio
  portfolio_value_i
  portfolio_value
  portfolio_value_history
  port_return_history
  avepr
  stdevpr
  network_in      ; weighting for network  - remains fixed
  private_in      ; weighting for private  - remains fixed
  public_in       ; weighting for public  - remains fixed
  switch_threshold
  tempPri
  tempPub
  tempNet
  trades
  actions
  dpsi
  IP
  friend_action      ;;;;
  friend_action_t-1  ;;;
  weight
  weightedfx
  weighted_action
  network_info_temp   ; rubbish why do I need this?
  friend_temp
  neighboraverage
  ttlnetwork
  ; Network stats for investors
  closeness
  betweenness
  eigen

]


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Set Up
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to set_up
  clear-all
 ; random-seed 100   ; if you want to recreate a bubble in H&S this seed works
  fill_globals
  create_assets
  setup_network
  populate_network_influence
  get_neighbor_ids      ; have to do this after to ensure all value are updated
 ;   network_stats      ; used to run network stats but very slow
  reset-ticks

end

to fill_globals
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;; At initialisation create the global lists. Length determined by the number of assets. Position relates to asset number
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

  set return_list []
  set return_list_t-1 []
  set esembled_average_t-1 []
  set esembled_average []
  set stddev_rt_1 []
  set stddev_rt []
  set price_list []
  set stdevpr_list []
  set avepr_list []
  set publicscore []
  set public_info []
  set public_info_t-1 []
  set effaave []
  set effastd []
  set dividends []

; Journal config..
;  set directory-name "/users/matthewoldham/Dropbox/Thesis/Model"
;  set-current-directory directory-name
  set file-name (word "journal.txt")
  output-type (word directory-name "/" file-name)
  file-close-all                          ;Close any open files

  if create-journal [
    if file-exists? file-name [file-delete file-name]
    file-open file-name
    file-print (word "0: Test Started at " date-and-time "\r\n")
  ]
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;; Need to the set initial returns and standard. Used to determine accuracy. Assume it should be 0 and 1
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

  let n 0
  while [ n < number_of_assets ]
  [ set esembled_average lput 0 esembled_average
    set stddev_rt lput 0.1 stddev_rt  ;; problem early may be for first move   0 or 1?????
    set return_list lput 0 return_list
    set publicscore lput 0 publicscore
    set n (n + 1)
  ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Creates the required number of assets (step 1 Figure 6)
;;  - All variables are initiated but depending on where the H&S model or revised model is used will determine whether they are utilised
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to create_assets
  let m 0
  while [ m < number_of_assets ]
  [
    create-assets 1
    [
      set size 5
      set beta corr_r
      set price 1.0  ;;; 1 big question as to whether to start - H & S say 1
      set bid_vol 0
      set ask_vol 0
      set price_list lput price price_list         ;;; global  price list for each tick

      set a_rt []
      set stdevrt []
      set H&S_dev (1 + m / 10)
      set eps_mean ((1 / 4) / 15 ) * 100
      set eps_dev (eps_mean * std_eps) + (m / 10)   ;; each asset becomes more volatile
      set eps_history []

      set consensus_eps eps_mean
      set ensemble_eps_t-1 eps_mean

  ; populate the history to allow the model to get started
      repeat Ring_M [
        set eps random-normal eps_mean eps_dev     ;;;
        set eps_history lput eps eps_history
        set ensemble_eps_t-1 consensus_eps
        set consensus_eps (memory_weight * ensemble_eps_t-1) + (1 - memory_weight) * eps
      ]
      set m (m + 1)
    ]
  ]



  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;; Need to create a list so assets are initiated in order during some procedures
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

  set assets_list [who] of assets
  set assets_list sort assets_list
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Set up the network (step 2 Figure 6)
;; - the user has the option of using four network types. Each uses the Netlogo network extension to generate the network
;; The base functionality here comes from the code provided by Steve Scott in the NetLogo class.
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to setup_network
  if network-type = "erdos_renyi" [ setup-erdos-renyi ]
  if network-type = "preferential_attachment" [ setup-preferential_attachment  ]
  if network-type = "small_world" [ setup-small_world ]
  if network-type = "ring" [ setup-ring ]
end

to setup-erdos-renyi
  nw:generate-random investors connections number_of_investors prob_of_link [layout_ring]
end

to setup-preferential_attachment
    create-investors number_of_investors [
    set size 1.0
    set shape "circle"
    let spot one-of patches with[not any? investors-here]
    ifelse (spot != nobody) [
      move-to spot
    ]
    [setxy random-pxcor random-pycor]
  ]

 ask investors [
    let  my-node self
    let degrees max-n-of Ring_M investors [count link-neighbors]
    foreach sort degrees [
      let chance random-float 1.0
      if (chance < prob_of_link) and (? != my-node) [
        ask my-node [
          create-link-with ?
        ]
      ]
    ]
  ]
end

to setup-small_world
  setup-ring

   foreach sort investors [
    ask ? [
      let temp sort link-neighbors
      foreach temp [
        if random-float 1.0 < prob_of_rewire [
          let x one-of other investors with [ abs (who - [who] of myself) > 2 ]
          if is-investor? x
          [
            ask link-with ? [ die ]
            create-link-with x
          ]
        ]
      ]
    ]
  ]
end

to setup-ring
  create-investors number_of_investors [
    set size 1.0
    set shape "circle"
    let spot one-of patches with[not any? investors-here]
    ifelse (spot != nobody) [
      move-to spot
    ]
    [setxy random-pxcor random-pycor]
  ]

  let node-list sort investors
  let i 0
  foreach node-list [
    let j ?
    let k 1
    let link-nodes []
    while [ k <= Ring_M ]
    [
      let ptr (i + k + (length node-list)) mod (length node-list)
      set link-nodes lput (item ptr node-list) link-nodes
      set k (k + 1)
    ]
    foreach link-nodes [
      set k ?
      ask j [ create-link-with k ]
    ]
    set i (i + 1)
  ]

  ask investors [layout_ring]
end

to layout
  let spot one-of patches with[not any? investors-here]
  ifelse (spot != nobody)
    [move-to spot]
    [setxy random-pxcor random-pycor]

end

to layout_ring
  layout-circle sort investors max-pxcor * 0.9
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; After the network is created the investor agents are populated with their various requirements (step 3 Figure 6)
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to populate_network_influence
  ask investors [
    set ID self                                             ;;;;  assign the ID so a list of neighbors can be formed
    set cash 1                                              ;;;;  as per H & S each investor gets 1 unit of cash
    set neighbor_trust []                                   ;;;;  initiate a list that will store how much you trust each neigbor
    set num_neighbors count link-neighbors                  ;;;;  determine how many neighbors you have
    if num_neighbors != 0                                   ;;;;  If number of neigbors you have is >0 you need to set an initial trust level 0
    [ let n 0
      while [ n < num_neighbors ]
      [
        set neighbor_trust lput 0 neighbor_trust             ;;;; initial trust is 0
        set n (n + 1) ]
    ]
    set private_in random-float private_influence    ;;;;   fixed value that determines your weight/bias to private info (c3 in H & S paper)
    set public_in random-float public_influence      ;;;;   fixed value that determines your weight/bias to public info (c2 in H & S paper)
    set network_in random-float network_influence    ;;;;   fixed value that determines your weight/bias to network info (c1 in H & S paper)
    set switch_threshold random-float threshold      ;;;;   the threshold value that an investor must meet to trade an asset
    set private_info []                              ;;;;   initiate the lists to put the various info for each asset
    set trades []
    set portfolio[]
    set portfolio_value_i[]
    set actions []
    set portfolio_value_history []
    set port_return_history []

    let q 0                                          ;;;;   provide 1 of each asset to the agents.
    while [ q < number_of_assets ]
      [
        set portfolio lput 1 portfolio
        set portfolio_value_i lput 1 portfolio_value_i
        set actions lput 0 actions
        set q (q + 1)
      ]

;; set the initial portfolio values and fill history
    set portfolio_value cash + sum portfolio_value_i
    set portfolio_value_history lput portfolio_value portfolio_value_history
    set closeness 0.000
  ]

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Each investor has to get a list of their neighbors
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to get_neighbor_ids
  ask investors [set neighbor_list [ID] of link-neighbors ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Step and Go
;; - do network stats independently and not on each run!
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to network_stats

  ask investors [
    set closeness  nw:closeness-centrality
    set betweenness nw:betweenness-centrality
    set eigen nw:eigenvector-centrality
  ]

  set average_betweenness mean [betweenness] of investors
  set average_closeness mean [closeness] of investors
  set average_eigen mean [eigen] of investors

  set std_betweenness standard-deviation [betweenness] of investors
  set std_closeness standard-deviation [closeness] of investors
  set std_eigen standard-deviation [eigen] of investors
end

to step
  asset_growth
  decision
  order_book
  clear_market

; can only update the weights after the first tick

  if ticks > 1 [
    public_weight_update
    neighbor_weight_update]
  investor_update
  if eff_frontier [portfolio_vaulation]
  stats
  tick
end

to go
  if ticks > 3000 [
    journal (word " Ended" )
  file-close-all
  stop]

  ; run profiler to find slow parts
 ; profiler:start
  step
 ; profiler:stop
 ; print profiler:report
 ; profiler:reset
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Need to update the earnings for each company (step 4 Figure 6) this feeds the public info (step 5 Figure 6)
;;  - the assets need to initiated in order otherwise the public_info list is pointless.
;;  - works through the list and asks each ask to [grow-H&S] for the H&S procedure or [grow_MO] for the extended model
;;  - dividend also declared but at this point not used - NEEDS TO COME INTO THE rt
;;  - in the extended model public info for each asset is determined by how closely the actual came in against the consensus estimate
;;  - This is justified because the history of an asset should be close to the consensus average
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to asset_growth
  set public_info_t-1 []
  set public_info_t-1 public_info
  set public_info []
  set dividends []


if H&S [ set asset_0_news random-normal 0 1
      set public_info lput asset_0_news public_info ]
  set asset_counter 0
  while [asset_counter < number_of_assets]
  [
    let next_asset item asset_counter assets_list
    ifelse H&S [
      ask asset next_asset [grow_H&S]
      ]

    [ ask asset next_asset [grow_MO]         ;;;;;;FIX FOR MYULTI
    if pay_out_ratio > 0 [pay_dividend]
    ]
    set asset_counter asset_counter + 1
  ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; To grow with the H&S
;; - pull a random variable from N(0,1) - tmp
;; - combine tmp and asset_0_ news based on the correlation to get the public info for this asset
;; - put it in the list so the population can see it
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to grow_H&S

      if asset_counter > 0
  [let tmp random-normal 0 H&S_Dev
  set consensus_accuracy (beta * asset_0_news) + ((1 - beta ) * tmp)
  set public_info lput consensus_accuracy public_info]

  journal (word "asset "  asset_counter  " has this public info " consensus_accuracy)

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; To grow with the MO model
;; - NB lacks the multi asset possibility at this point
;; - pull the eps from the distribution of N(eps_mean ,eps_dev)
;; - if EPS is > declare the divided - NB /100 to get back into $ form
;; - update the lists and history
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to grow_MO

  set eps random-normal eps_mean eps_dev

  if eps > 0
    [set dps (eps * pay_out_ratio) / 100]

  set eps_history lput eps eps_history
  set dividends lput dps dividends
  set consensus_accuracy (eps - consensus_eps )/ consensus_eps    ;;; ISSUE

  journal (word "asset " who " has this public info " consensus_accuracy)

  set public_info lput consensus_accuracy public_info
  journal (word "asset "  asset_counter  " has this public info " consensus_accuracy)

  set ensemble_eps_t-1 consensus_eps
  set consensus_eps (memory_weight * ensemble_eps_t-1) + (1 - memory_weight) * eps

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Dividend bank
;; - put the dividend in the dividend bank for each of the investors
;; - get the holding of the investor and times by the dividends declared above
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to pay_dividend

  ask investors [
    set dpsi sum (map * portfolio dividends)
    set dividend_bank dpsi + (dividend_bank) ]

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Agents make their decision for each stock (step 6 Figure 6). For this they need to update the following
;; - Private info - done via the update private info procedure
;; - Network info - done via the update_neighbor_info procedure. Is conditionalal on having a neighbor
;; - Public info - only need to access the public info list which was updated in the prior procedure [asset-growth]
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to decision
  ask investors [                                ;;;;;; random order to the initiation of the agents.NB H & S had similar
    set trades []
    set actions []

    update_private_info

    if num_neighbors > 0
    [update_neighbor_info]                       ;;;;;; provides poll of neighbors

    let d 0
    while [ d < number_of_assets ]

    [ set IP 0                                                    ;; clear IP for best practice
      let stock_price item d price_list                           ;; getting stock price to work out the trading costs
      let holding item d portfolio                                ;; select the holding for each particular asset

      set tempPri item d private_info  * private_in                     ;; get the private info for the particular asset and times by bias/weight
      set tempPub item d public_info * public_in * item d publicscore   ;; takes the fixed weight public_in * (publicinfo * trust_coefficient)
      if num_neighbors > 0
      [ set tempNet item d network_info   ]                          ;; already done so just return the value

      set IP tempPri + tempPub + tempNet                          ;;

      ifelse IP > switch_threshold                                ;; buy if IP is greater than your threshold

      [ set actions lput 1 actions                               ;;  Must have cash to trade but opinion still counts
        ifelse cash > 0
        [
          let trans transaction_ratio * (cash / stock_price)
          set trades lput trans trades]
        [ set trades lput 0 trades]
      ]

      [ifelse IP < (switch_threshold * -1 )                        ;; sell if IP is less than the negative of your threshold BUT must have an asset

        [ set actions lput -1 actions                               ;; opinion still counts regardlessof holding or not
          ifelse holding > 0 [
            set trades lput (transaction_ratio * holding * -1 ) trades
          ]
          [ set trades lput 0 trades  ]
        ]
        [
          set trades lput 0 trades                                  ;; hold or no action otherwise
          set actions lput 0 actions]
      ]
      set d (d + 1)
    ]
  ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; To get the new private info the following occurs (step 5 Figure 6)
;; - get a random value within the given distribution news~N(0,1) and then multiple by the agent's weighting to public info
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to update_private_info
  set private_info n-values number_of_assets [new_private_analysis]
end

to-report new_private_analysis
  let prinews (random-normal 0 1)
  report prinews
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Need to assess network info (one part of step 5 Figure 6)
;; - To update the network info the following occurs - Remember this called by the decision procedure and is done for each agent
;; - initiate/blank out the previous lists
;; - then starting at a particlar neighbor get the "trust" you have in them
;; - then for that neighbor get their actions for asset a - will be -1,0 or 1
;; - next multiple that action by the trust level (kij(t - 1) H&S)
;; - repeat for all assets
;; - then repeat for all neighbors and populate the list of lists - friend_action and weighted_action
;; - next step detailed below
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to update_neighbor_info
  set network_info_t-1 []
  set network_info_t-1 network_info
  set network_info []                                   ;; this is used until the last bit and hold the
  let fx []
  set friend_action_t-1 []
  set friend_action_t-1 friend_action
  set friend_action []
  set weighted_action []
  set network_info_temp []
  let d 0
  while [ d < num_neighbors ]

  [ set weight item d neighbor_trust
    let a 0
    while [ a < number_of_assets ]

    [ set fx lput [item a actions] of item d neighbor_list fx
      set weightedfx  map [? * weight] fx
      set a (a + 1)
    ]
    set friend_action lput fx friend_action
    set weighted_action lput weightedfx weighted_action        ;; so this is right
    set fx []                                              ;; clear it ready for the next neighbor
    set d (d + 1)
  ]

  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;; Now you need to combine all the network infomation for each asset. To achieve this
  ;; - use the map function to sum asset q from weighted_action - gives the combined weight for the particular asset for all the neighbors
  ;; - then put that result into another list - probably could have reduced but easier to do this
  ;; - once we have the list we need to * it by the network_in constant (1 in H&S)
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

  let q 0
  while [ q < number_of_assets ]

  [ let temp sum map [item q ? ] weighted_action
    set network_info_temp lput temp network_info_temp
    set q (q + 1)
  ]
  set network_info map [(? * network_in) ] network_info_temp
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; The order book is created in the following manner (step 7 Figure 6):
;; - initiate the various lists - order bank being the combined list of order_bank_all, which is a list of list that
;;   that contains each investors orders for each asset
;; - order_bank_all is populated it is summed over to get trades for each asset
;; - NB the order it collects the trades from each investor does not matter. But the trade list will be in the right order for assets
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to order_book
  set order_bank []
  set order_bank_all []
  set order_bank_all [trades] of investors


  set buying_list []
  set selling_list []
  set action_bank_all []
  set action_bank_all [actions] of investors

  let x 0
  while [ x < number_of_assets ]
  [ let temp sum map [item x ? ] order_bank_all
    set order_bank lput temp order_bank
    set x (x + 1)
  ]
  set buying 0
  set selling 0
  let y 0
  while [ y < number_of_assets ]
    [
      set temp2 map [item y ? ] action_bank_all

      let z 0
      while [ z < number_of_investors ]
      [
        if item z temp2 = 1 [set buying buying + 1]
        if item z temp2 = -1 [set selling selling + 1]
        set z (z + 1)

      ]
      set buying_list lput buying buying_list
      set selling_list lput selling selling_list
      set buying 0
      set selling 0
      set y (y + 1) ]

  let p 0
  while [ p < number_of_assets ]
    [ ask asset p
      [
        set bid_vol  item p buying_list
        set ask_vol  item p selling_list
        set p (p + 1)
      ]
    ]

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; To Update Price (step 8 Figure 6)
;; - use the clear market function
;; - NB need to determine the return minus the dividend first (return_temp). Why? to get the new price
;; - Once the new price is determined if using the extended model then set the return as the price return plus the dividend
;; - After the return(s) have been determined then the esembled average needs to be updated
;; - This allows for the factor variable to be update, which is needed to update the trust levels
;; - Finally new price is transferred to the actual asset. Why? to allow for the calculation of the mean and std dev of the asset's returns
;; - NB unlogging to get common base for the use in the efficient frontier
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to clear_market

  ;;;;;
  ;; updates the assets at a global level
  ;;;;;

  set price_list_temp price_list
  set return_list_t-1 return_list
  set return_list []
  set esembled_average_t-1 esembled_average
  set esembled_average []
  set stddev_rt_1 stddev_rt
  set stddev_rt []
  set price_list []

  let j 0
  while [ j < number_of_assets ]

    [ let temp_orders item j order_bank

      let return_temp (1 / (number_of_investors * market_depth )) * temp_orders   ;  return global? may be not - could be let -> must see that it works ok

      set newpricelog (log (item j price_list_temp) 10) + return_temp      ;; this works now. Issue is size of r...
      let newprice 10 ^ newpricelog
      set price_list lput newprice price_list

      ifelse H&S
      [let div 0
       set return return_temp + log ((newprice + div) / newprice) 10 ]

       [ let div item j dividends

      set return return_temp + log ((newprice + div) / newprice) 10 ]

      set return_list lput return return_list                                 ; need to update asset later  this could be ugly figure

      let esrt memory_weight * item j esembled_average_t-1 + ( 1 - memory_weight) * item j return_list  ; took out t-1

      journal (word "asset "  j  " has this esembled return " esrt)

      set esembled_average lput esrt esembled_average

      let varrt (memory_weight * (item j stddev_rt_1 ^ 2)) + (( 1 - memory_weight ) * ( item j return_list - item j esembled_average ) ^ 2) ; took out t-1

      let stddevrtj (varrt) ^ .5

      set stddev_rt lput stddevrtj stddev_rt

      let facto return / stddevrtj

      journal (word "asset "  j  " has this return " return)
      journal (word "asset " j " has this stdev " stddevrtj)
      journal (word "asset "  j " has this factor " facto)

      ask asset j [                              ;; asset j ensures that it gets the right history
        set price item j price_list
        set rti item j return_list

        let non_log_rti (10 ^ rti) - 1
        set a_rt lput non_log_rti a_rt

        let stdevrti item j stddev_rt
        set stdevrt lput stdevrti stdevrt
      ]
      set j (j + 1)
    ]

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; To update investor porftolio (step 11 Figure 6)
;; - straight forward book keeping- simply taking old holding and add and subtract new holdings and cash
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to investor_update
  ask investors [
    let portfolio_temp portfolio
    set portfolio []
    let p 0
    while [ p < number_of_assets ]

    [ let newholding (item p portfolio_temp + item p trades)     ; add here  buys is positive while sale is a negative value for trade
      set portfolio lput newholding portfolio
      let proceeds (item p trades * item p price_list)
      set cash cash - proceeds                                   ; minus here  buys is positive while sale is a negative value for trade
                                                                 ;  set dpsi [dps] of asset p
                                                                 ;  let holding item p portfolio
                                                                 ;  set cash cash + dpsi * holding    ;;;; check  - should this be inclcuded in the return??
      set p (p + 1)
    ]
  ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; To upadate the value of the new portfolio holdings (step 12 Figure 6)
;; - Place old portfolio value in a t-1 list
;; - Determine new value for the portfolio
;; - Work out returns and then average and std dev
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to portfolio_vaulation

  set avepr_list []
  set stdevpr_list []
  ask investors [

    let portfolio_value_t-1 portfolio_value
    set portfolio_value_i []
    let t 0
    while [ t < number_of_assets ]

    [let value (item t portfolio * item t price_list)
      set portfolio_value_i lput value portfolio_value_i
      set t (t + 1)
    ]
    set portfolio_value sum portfolio_value_i + dividend_bank ;+ cash  not used as eff_frontier only tested for H&S at this point
    set portfolio_value_history lput portfolio_value portfolio_value_history
    let portfolio_return (portfolio_value / portfolio_value_t-1 ) - 1
    set port_return_history lput portfolio_return port_return_history

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; To plot the efficient frontier need to:
;; - get the average return for each investor
;; - place each investor's average return in a list to use in the plot below
;; - repeat for std
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

    if ticks > 2            ;; only start after 2 as need at least 2 values to get std dev.
    [
      set avepr mean port_return_history
      set avepr_list lput avepr avepr_list
      set stdevpr standard-deviation port_return_history
      set stdevpr_list lput stdevpr stdevpr_list]
  ]

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; To plot the efficient frontier need to get the stats of the assets
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

  if ticks > 1 [

    set effaave []
    set effastd  []
    ask assets
    [
      set ave_return mean a_rt
      set stddev_a_rt standard-deviation a_rt

      set effaave lput ave_return effaave
      set effastd lput stddev_a_rt effastd
    ]
  ]

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Trust  Update (Step 9 ) in figure 6
;; - Update public trust first by:
;; - get previous trust and place it into the old trust variable
;; - determine factor again
;; - apply formula to get new score (that is trust for that asset)
;; - place trust for the asset into the gloabl list
;; - take the average to get the public_trust variable that is used for plotting only
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to public_weight_update
  let oldpublic_trust publicscore
  set publicscore []
  set public_trust 0                                  ; clear this variable for best practice
  let s 0
  while [s <  number_of_assets ]

    [
      set factor (item s return_list / item s stddev_rt)
      let score (memory_weight * item s oldpublic_trust) + ((1 - memory_weight) * (item s public_info_t-1) * factor )  ;return by variance
      set publicscore lput score publicscore;
      journal (word "the world has this public score " score)
      set s (s + 1)
    ]

  set public_trust mean publicscore                 ;; used for plotting only. It is the public score that is used in the decision making pross
  journal (word "the world has this public averagre score " public_trust)
  set oldpublic_trust []

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Trust  Update (Step 10) in figure 6
;; - Update neigbor trust first by:
;; - set up temp lists to cycle through and clear current trust
;; - get previous trust and place it into the old trust variable
;; - for each neighbor get there actions
;; - determine factor again
;; - apply formula to get new score (that is trust for that asset)
;; - place trust for the asset into the list and repeat for each asset
;; - take the average of the performance of the  neighbor for the all asset and place into the neighbor_trust list to be used in the decision making
;; - finally ttlnetwork updated to get the average trust the investor has in all their neighbors
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to neighbor_weight_update     ; what is this updating though?

  ask investors[
    set neighbor_trust_temp []
    set neighbor_trust_temp neighbor_trust
    set neighbor_trust []
    let nws []                   ;;change this later
    let x 0
    while [x < num_neighbors ]

    [ set friend_temp []

      let nw item x neighbor_trust_temp
      set friend_temp item x friend_action_t-1    ;;;;;
      let a 0
      while [ a < number_of_assets ]

      [ let factorN (item a return_list / item a stddev_rt)
        let newtrust ((memory_weight * nw) + ((1 - memory_weight) * (item a friend_temp) * factorN))             ;;;; Friend info needs to go to t-1
        set nws lput newtrust nws
        set a (a + 1)
      ]

      set neighboraverage mean nws                            ;;;
      set neighbor_trust lput neighboraverage neighbor_trust  ;
      set nws []
      set x (x + 1)
    ]
    ifelse num_neighbors > 0
    [set ttlnetwork (mean neighbor_trust)]
    [set ttlnetwork 0]
  ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Stats
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to stats
  confidence
  cash_holding
end

to confidence
  set network_trust mean [ttlnetwork] of investors
end

to efficient_frontier
  clear-plot
  (foreach stdevpr_list avepr_list [plotxy ?1 ?2])
end

to asset_plot
  (foreach effastd effaave [plotxy ?1 ?2])
end

to  cash_holding
  set-current-plot "cash holdings"
  set-plot-x-range 0 2
  set-plot-y-range 0 36
  set-histogram-num-bars 10
  histogram [ cash ] of investors
end

to journal [text]
  if create-journal [
    file-print (word ticks ": " text "\r\n")
    file-print ""
  ]
end
@#$#@#$#@
GRAPHICS-WINDOW
810
15
1183
409
75
75
2.404
1
10
1
1
1
0
0
0
1
-75
75
-75
75
0
0
1
ticks
30.0

SLIDER
5
100
177
133
number_of_assets
number_of_assets
1
20
5
1
1
NIL
HORIZONTAL

SLIDER
205
95
391
128
number_of_investors
number_of_investors
5
2500
2500
5
1
NIL
HORIZONTAL

TEXTBOX
7
10
316
29
Multi Asset Model
18
104.0
1

TEXTBOX
10
84
160
102
Market Characteristics
11
0.0
1

TEXTBOX
205
80
355
98
Agent Characteristics
11
0.0
1

TEXTBOX
405
80
555
98
Network Characteristics
11
0.0
1

TEXTBOX
605
80
755
98
Output Options
11
0.0
1

BUTTON
8
40
81
73
NIL
set_up
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
84
41
147
74
NIL
step
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
149
41
212
74
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
5
170
177
203
market_depth
market_depth
0
1
0.25
.05
1
NIL
HORIZONTAL

SLIDER
205
165
377
198
threshold
threshold
0.2
3
2
.02
1
NIL
HORIZONTAL

SLIDER
205
200
377
233
transaction_ratio
transaction_ratio
0.01
.5
0.02
.01
1
NIL
HORIZONTAL

SLIDER
205
235
377
268
network_influence
network_influence
0
5
1
1
1
NIL
HORIZONTAL

SLIDER
205
270
377
303
private_influence
private_influence
0
5
1
1
1
NIL
HORIZONTAL

SLIDER
205
305
377
338
public_influence
public_influence
0
5
1
1
1
NIL
HORIZONTAL

SLIDER
205
130
377
163
memory_weight
memory_weight
0.05
1
0.95
.05
1
NIL
HORIZONTAL

PLOT
400
255
770
445
asset price
NIL
NIL
0.0
10.0
0.9
1.1
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot [price] of asset 0"

CHOOSER
405
95
597
140
network-type
network-type
"erdos_renyi" "ring" "small_world" "preferential_attachment"
1

SLIDER
405
175
577
208
prob_of_link
prob_of_link
0
.5
0.04
.001
1
NIL
HORIZONTAL

MONITOR
5
330
125
375
count links
count links
17
1
11

MONITOR
5
280
125
325
NIL
count investors
17
1
11

PLOT
780
530
1185
715
trust levels
NIL
NIL
0.0
10.0
-0.03
0.03
true
true
"" ""
PENS
"PT" 1.0 0 -2674135 true "" "plot public_trust"
"NT" 1.0 0 -7500403 true "" "plot network_trust"

MONITOR
5
380
95
425
non traders
count investors with [cash = 1]
17
1
11

MONITOR
5
430
180
475
NIL
network_trust
17
1
11

PLOT
400
450
770
615
returns
NIL
NIL
0.0
10.0
0.0
0.02
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot [rti] of asset 0"

SLIDER
405
140
577
173
Ring_M
Ring_M
0
20
2
1
1
NIL
HORIZONTAL

PLOT
780
255
1185
525
Eff_Frontier
Std PR
PR
0.0
1.0E-6
0.0
1.0E-4
true
false
"" ""
PENS
"default" 1.0 2 -16777216 true "" "efficient_frontier"
"pen-1" 2.0 2 -3844592 true "" "asset_plot"

SWITCH
605
130
747
163
create-journal
create-journal
1
1
-1000

PLOT
400
620
775
800
factor vs public trust
NIL
NIL
0.0
10.0
-4.0
4.0
true
true
"" ""
PENS
"factor" 1.0 0 -16777216 true "" "plot factor"
"pt" 1.0 0 -3844592 true "" "plot public_trust"

SWITCH
605
95
708
128
H&S
H&S
0
1
-1000

PLOT
185
345
385
495
cash holdings
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 1 -16777216 true "" ""

SLIDER
5
135
180
168
pay_out_ratio
pay_out_ratio
0
1
0.5
.1
1
NIL
HORIZONTAL

PLOT
190
500
390
650
EPS/Con
NIL
NIL
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot [eps] of asset 0"
"pen-1" 1.0 0 -7500403 true "" "plot [consensus_eps ] of asset 0"

SLIDER
5
205
177
238
corr_r
corr_r
0
1
1
.1
1
NIL
HORIZONTAL

SWITCH
605
165
732
198
eff_frontier
eff_frontier
1
1
-1000

SLIDER
405
210
577
243
prob_of_rewire
prob_of_rewire
0
1
0.1
.05
1
NIL
HORIZONTAL

SLIDER
5
240
177
273
std_eps
std_eps
0
1
0.5
.1
1
NIL
HORIZONTAL

TEXTBOX
25
705
175
723
User Notes
14
0.0
1

TEXTBOX
25
725
320
861
- The H&S switch allows the model to run either the extennded model or the original H&S model.\n- The create-journal switch is straight foward\n- If the user wants to see the efficient frontier turn switch on but it slows the model down\n
11
0.0
1

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -7500403 true true 135 285 195 285 270 90 30 90 105 285
Polygon -7500403 true true 270 90 225 15 180 90
Polygon -7500403 true true 30 90 75 15 120 90
Circle -1 true false 183 138 24
Circle -1 true false 93 138 24

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.3
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="Replication" repetitions="1" runMetricsEveryStep="true">
    <setup>set_up</setup>
    <go>go</go>
    <timeLimit steps="3000"/>
    <metric>public_trust</metric>
    <metric>network_trust</metric>
    <metric>[price] of asset 0</metric>
    <metric>[rti] of asset 0</metric>
    <metric>factor</metric>
    <metric>[bid_vol] of asset 0</metric>
    <metric>[ask_vol] of asset 0</metric>
    <metric>asset_0_news</metric>
    <enumeratedValueSet variable="prob_of_rewire">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="transaction_ratio">
      <value value="0.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="market_depth">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="create-journal">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory_weight">
      <value value="0.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob_of_link">
      <value value="0.002"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;ring&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="std_eps">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="private_influence">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="H&amp;S">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pay_out_ratio">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="corr_r">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="test" repetitions="30" runMetricsEveryStep="true">
    <setup>set_up</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>[price] of asset 0</metric>
    <metric>[rti] of asset 0</metric>
    <metric>factor</metric>
    <metric>[bid_vol] of asset 0</metric>
    <metric>[ask_vol] of asset 0</metric>
    <metric>[consensus_accuracy] of asset 0</metric>
    <enumeratedValueSet variable="Ring_M">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="transaction_ratio">
      <value value="0.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="create-journal">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pay_out_ratio">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="public_influence">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="clustering_exponent">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="private_influence">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory_weight">
      <value value="0.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_of_investors">
      <value value="2500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="market_depth">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;ring&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_of_assets">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prod_of_link">
      <value value="0.002"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network_influence">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="H&amp;S">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="corr_r">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="dividends" repetitions="30" runMetricsEveryStep="true">
    <setup>set_up</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>[price] of asset 0</metric>
    <metric>[rti] of asset 0</metric>
    <metric>factor</metric>
    <metric>[bid_vol] of asset 0</metric>
    <metric>[ask_vol] of asset 0</metric>
    <metric>[consensus_accuracy] of asset 0</metric>
    <metric>[eps] of asset 0</metric>
    <metric>public_trust</metric>
    <enumeratedValueSet variable="create-journal">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pay_out_ratio">
      <value value="0"/>
      <value value="0.33"/>
      <value value="0.66"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_of_investors">
      <value value="2500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="H&amp;S">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="market_depth">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prod_of_link">
      <value value="0.002"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="corr_r">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory_weight">
      <value value="0.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Ring_M">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="transaction_ratio">
      <value value="0.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network_influence">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;ring&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="clustering_exponent">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="private_influence">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="public_influence">
      <value value="1"/>
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_of_assets">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="correlation" repetitions="30" runMetricsEveryStep="true">
    <setup>set_up</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>[price] of asset 0</metric>
    <metric>[price] of asset 1</metric>
    <metric>[price] of asset 2</metric>
    <metric>[rti] of asset 0</metric>
    <metric>[rti] of asset 1</metric>
    <metric>[rti] of asset 2</metric>
    <metric>item 0 publicscore</metric>
    <metric>item 1 publicscore</metric>
    <metric>item 2 publicscore</metric>
    <enumeratedValueSet variable="create-journal">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pay_out_ratio">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_of_investors">
      <value value="2500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="H&amp;S">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="market_depth">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prod_of_link">
      <value value="0.002"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="corr_r">
      <value value="0"/>
      <value value="0.33"/>
      <value value="0.66"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory_weight">
      <value value="0.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Ring_M">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="transaction_ratio">
      <value value="0.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network_influence">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;ring&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="clustering_exponent">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="private_influence">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="public_influence">
      <value value="1"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_of_assets">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="swnew" repetitions="30" runMetricsEveryStep="true">
    <setup>set_up</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>public_trust</metric>
    <metric>network_trust</metric>
    <metric>[price] of asset 0</metric>
    <metric>[rti] of asset 0</metric>
    <metric>factor</metric>
    <metric>[bid_vol] of asset 0</metric>
    <metric>[ask_vol] of asset 0</metric>
    <metric>[consensus_accuracy] of asset 0</metric>
    <enumeratedValueSet variable="private_influence">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob_of_link">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;small_world&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="public_influence">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="corr_r">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="create-journal">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pay_out_ratio">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network_influence">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="market_depth">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="transaction_ratio">
      <value value="0.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eff_frontier">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_of_assets">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_of_investors">
      <value value="2500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Ring_M">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="H&amp;S">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory_weight">
      <value value="0.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob_of_rewire">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ernew" repetitions="30" runMetricsEveryStep="true">
    <setup>set_up</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>public_trust</metric>
    <metric>network_trust</metric>
    <metric>[price] of asset 0</metric>
    <metric>[rti] of asset 0</metric>
    <metric>factor</metric>
    <metric>[bid_vol] of asset 0</metric>
    <metric>[ask_vol] of asset 0</metric>
    <metric>[consensus_accuracy] of asset 0</metric>
    <enumeratedValueSet variable="private_influence">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob_of_link">
      <value value="0.0016"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;erdos_renyi&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="public_influence">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="corr_r">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="create-journal">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pay_out_ratio">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network_influence">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="market_depth">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="transaction_ratio">
      <value value="0.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eff_frontier">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_of_assets">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_of_investors">
      <value value="2500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Ring_M">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="H&amp;S">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory_weight">
      <value value="0.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob_of_rewire">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
1
@#$#@#$#@
